tlslite.integration

Package tlslite :: Package integration |
[show private | hide private]
[frames | no frames]

## Package tlslite.integration

Classes for integrating TLS Lite with other packages.

Submodules
`AsyncStateMachine`: A state machine for using TLS Lite with asynchronous I/O. `HTTPTLSConnection`: TLS Lite + httplib. `IMAP4_TLS`: TLS Lite + imaplib. `POP3_TLS`: TLS Lite + poplib. `SMTP_TLS`: TLS Lite + smtplib. `TLSAsyncDispatcherMixIn`: TLS Lite + asyncore. `TLSSocketServerMixIn`: TLS Lite + SocketServer. `TLSTwistedProtocolWrapper`: TLS Lite + Twisted. `XMLRPCTransport`: TLS Lite + xmlrpclib.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net